@@ -99,7 +99,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( );
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 our $LASTERROR;
 
@@ -155,6 +155,9 @@ sub new
 					return (undef);
 				}
 				$params{'Family'} = $AF_INET6;
+				if ($^O ne 'MSWin32') {
+					$params{'V6Only'} = 1;
+				}
 			}
 		}
 		else
